@@ -118,6 +118,7 @@ func newRootCmd(ctx *config.RunContext) *cobra.Command {
 		PersistentPreRunE: func(cmd *cobra.Command, args []string) error {
 			cmd.SilenceUsage = true
 			ctx.SetContextValue("command", cmd.Name())
+			ctx.CMD = cmd.Name()
 			if cmd.Name() == "comment" || (cmd.Parent() != nil && cmd.Parent().Name() == "comment") {
 				ctx.SetIsInfracostComment()
 			}
@@ -255,7 +256,7 @@ func checkAPIKey(apiKey string, apiEndpoint string, defaultEndpoint string) erro
 	if apiEndpoint == defaultEndpoint && apiKey == "" {
 		return fmt.Errorf(
 			"No INFRACOST_API_KEY environment variable is set.\nWe run a free Cloud Pricing API, to get an API key run %s",
-			ui.PrimaryString("infracost register"),
+			ui.PrimaryString("infracost auth login"),
 		)
 	}
 
