@@ -14,12 +14,14 @@ import (
 	"github.com/shopspring/decimal"
 	"golang.org/x/mod/semver"
 
+	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/schema"
 )
 
 var (
-	minOutputVersion = "0.2"
-	maxOutputVersion = "0.2"
+	minOutputVersion     = "0.2"
+	maxOutputVersion     = "0.2"
+	GitHubMaxMessageSize = 262144
 )
 
 type ReportInput struct {
@@ -164,7 +166,10 @@ func Combine(inputs []ReportInput) (Root, error) {
 	summaries := make([]*Summary, 0, len(inputs))
 	currency := ""
 
-	for _, input := range inputs {
+	var metadata Metadata
+	var invalidMetadata bool
+	builder := strings.Builder{}
+	for i, input := range inputs {
 		var err error
 		currency, err = checkCurrency(currency, input.Root.Currency)
 		if err != nil {
@@ -218,6 +223,13 @@ func Combine(inputs []ReportInput) (Root, error) {
 
 			diffTotalHourlyCost = decimalPtr(diffTotalHourlyCost.Add(*input.Root.DiffTotalHourlyCost))
 		}
+
+		if i != 0 && metadata.VCSRepoURL != input.Root.Metadata.VCSRepoURL {
+			invalidMetadata = true
+		}
+
+		metadata = input.Root.Metadata
+		builder.WriteString(fmt.Sprintf("%q, ", input.Root.Metadata.VCSRepoURL))
 	}
 
 	combined.Version = outputVersion
@@ -231,6 +243,15 @@ func Combine(inputs []ReportInput) (Root, error) {
 	combined.DiffTotalMonthlyCost = diffTotalMonthlyCost
 	combined.TimeGenerated = time.Now().UTC()
 	combined.Summary = MergeSummaries(summaries)
+	combined.Metadata = metadata
+
+	if invalidMetadata {
+		return combined, clierror.NewWarningF(
+			"combining Infracost JSON for different VCS repositories %s. Using %s as the top-level repository in the outputted JSON",
+			strings.TrimRight(builder.String(), ", "),
+			metadata.VCSRepoURL,
+		)
+	}
 
 	return combined, nil
 }
@@ -271,7 +292,9 @@ func FormatOutput(format string, r Root, opts Options) ([]byte, error) {
 		b, err = ToHTML(r, opts)
 	case "diff":
 		b, err = ToDiff(r, opts)
-	case "github-comment", "gitlab-comment", "azure-repos-comment":
+	case "github-comment":
+		b, err = ToMarkdown(r, opts, MarkdownOptions{MaxMessageSize: GitHubMaxMessageSize})
+	case "gitlab-comment", "azure-repos-comment":
 		b, err = ToMarkdown(r, opts, MarkdownOptions{})
 	case "bitbucket-comment":
 		b, err = ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true})
