@@ -10,8 +10,9 @@ func getSNSTopicSubscriptionRegistryItem() *schema.RegistryItem {
 		Name:  "aws_sns_topic_subscription",
 		RFunc: NewSNSTopicSubscription,
 		Notes: []string{
-			"SMS and mobile push not yet supported.",
+			"DEPRECATED.  Set subscription usage on aws_sns_topic instead.",
 		},
+		ReferenceAttributes: []string{"topic_arn"},
 	}
 }
 
