@@ -33,12 +33,13 @@ type Instance struct {
 	EBSBlockDevices                 []*EBSVolume
 
 	// "usage" args
-	OperatingSystem               *string `infracost_usage:"operating_system"`
-	ReservedInstanceType          *string `infracost_usage:"reserved_instance_type"`
-	ReservedInstanceTerm          *string `infracost_usage:"reserved_instance_term"`
-	ReservedInstancePaymentOption *string `infracost_usage:"reserved_instance_payment_option"`
-	MonthlyCPUCreditHours         *int64  `infracost_usage:"monthly_cpu_credit_hrs"`
-	VCPUCount                     *int64  `infracost_usage:"vcpu_count"`
+	OperatingSystem               *string  `infracost_usage:"operating_system"`
+	ReservedInstanceType          *string  `infracost_usage:"reserved_instance_type"`
+	ReservedInstanceTerm          *string  `infracost_usage:"reserved_instance_term"`
+	ReservedInstancePaymentOption *string  `infracost_usage:"reserved_instance_payment_option"`
+	MonthlyCPUCreditHours         *int64   `infracost_usage:"monthly_cpu_credit_hrs"`
+	VCPUCount                     *int64   `infracost_usage:"vcpu_count"`
+	MonthlyHours                  *float64 `infracost_usage:"monthly_hrs"`
 }
 
 var InstanceUsageSchema = []*schema.UsageItem{
@@ -48,6 +49,7 @@ var InstanceUsageSchema = []*schema.UsageItem{
 	{Key: "reserved_instance_payment_option", DefaultValue: "", ValueType: schema.String},
 	{Key: "monthly_cpu_credit_hrs", DefaultValue: 0, ValueType: schema.Int64},
 	{Key: "vcpu_count", DefaultValue: 0, ValueType: schema.Int64},
+	{Key: "monthly_hrs", DefaultValue: 730, ValueType: schema.Float64},
 }
 
 func (a *Instance) PopulateUsage(u *schema.UsageData) {
@@ -173,11 +175,16 @@ func (a *Instance) computeCostComponent() *schema.CostComponent {
 		purchaseOptionLabel = "reserved"
 	}
 
+	qty := decimal.NewFromFloat(730)
+	if a.MonthlyHours != nil {
+		qty = decimal.NewFromFloat(*a.MonthlyHours)
+	}
+
 	return &schema.CostComponent{
-		Name:           fmt.Sprintf("Instance usage (%s, %s, %s)", osLabel, purchaseOptionLabel, a.InstanceType),
-		Unit:           "hours",
-		UnitMultiplier: decimal.NewFromInt(1),
-		HourlyQuantity: decimalPtr(decimal.NewFromInt(1)),
+		Name:            fmt.Sprintf("Instance usage (%s, %s, %s)", osLabel, purchaseOptionLabel, a.InstanceType),
+		Unit:            "hours",
+		UnitMultiplier:  decimal.NewFromInt(1),
+		MonthlyQuantity: decimalPtr(qty),
 		ProductFilter: &schema.ProductFilter{
 			VendorName:    strPtr("aws"),
 			Region:        strPtr(a.Region),
@@ -197,11 +204,27 @@ func (a *Instance) computeCostComponent() *schema.CostComponent {
 }
 
 func (a *Instance) ebsOptimizedCostComponent() *schema.CostComponent {
+	/**
+	 * EBS Optimized instances are billed hourly whenever the attached instance is live.
+	 *
+	 * From the EBS-opimized instance docs:
+	 *    > For Current Generation Instance types, EBS-optimization is enabled by default
+	 *    > at no additional cost. For Previous Generation Instances types, EBS-optimization
+	 *    > prices are on the Previous Generation Pricing Page.
+	 *    >
+	 *    > The hourly price for EBS-optimized instances is in addition to the hourly usage fee
+	 *    > for supported instance types.
+	 */
+	qty := decimal.NewFromFloat(730)
+	if a.MonthlyHours != nil {
+		qty = decimal.NewFromFloat(*a.MonthlyHours)
+	}
+
 	return &schema.CostComponent{
 		Name:                 "EBS-optimized usage",
 		Unit:                 "hours",
 		UnitMultiplier:       decimal.NewFromInt(1),
-		HourlyQuantity:       decimalPtr(decimal.NewFromInt(1)),
+		MonthlyQuantity:      decimalPtr(qty),
 		IgnoreIfMissingPrice: true,
 		ProductFilter: &schema.ProductFilter{
 			VendorName:    strPtr("aws"),
@@ -236,11 +259,23 @@ func (a *Instance) detailedMonitoringCostComponent() *schema.CostComponent {
 }
 
 func (a *Instance) elasticInferenceAcceleratorCostComponent() *schema.CostComponent {
+	/**
+	 * Elastic inference accelerators are billed hourly whenever the attached instance is live.
+	 *
+	 * From the elastic inference accelerator  docs:
+	 *    > With Amazon Elastic Inference, you pay only for the accelerator hours you use.
+	 *    > There are no upfront costs or minimum fees.
+	 */
+	qty := decimal.NewFromFloat(730)
+	if a.MonthlyHours != nil {
+		qty = decimal.NewFromFloat(*a.MonthlyHours)
+	}
+
 	return &schema.CostComponent{
-		Name:           fmt.Sprintf("Inference accelerator (%s)", strVal(a.ElasticInferenceAcceleratorType)),
-		Unit:           "hours",
-		UnitMultiplier: decimal.NewFromInt(1),
-		HourlyQuantity: decimalPtr(decimal.NewFromInt(1)),
+		Name:            fmt.Sprintf("Inference accelerator (%s)", strVal(a.ElasticInferenceAcceleratorType)),
+		Unit:            "hours",
+		UnitMultiplier:  decimal.NewFromInt(1),
+		MonthlyQuantity: decimalPtr(qty),
 		ProductFilter: &schema.ProductFilter{
 			VendorName:    strPtr("aws"),
 			Region:        strPtr(a.Region),
